@@ -18,18 +18,18 @@ SELECT * from pgr_trsp(
     true, true);
 
 PREPARE q21 AS
-SELECT seq, id1, id2, cost::text from pgr_trsp(
+SELECT seq, id1, id2,   round(cost::numeric, 3) from pgr_trsp(
     'select  id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost from edge_table',
     1, 3,
     true, true);
 
 PREPARE q22 AS
-SELECT seq-1, node::INTEGER, edge::INTEGER, cost::text from pgr_dijkstra(
+SELECT seq-1, node::INTEGER, edge::INTEGER, round(cost::numeric, 3) from pgr_dijkstra(
     'select  id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost from edge_table',
     1, 3, true);
 
 PREPARE q31 AS
-SELECT seq, id1, id2, cost::text from pgr_trsp(
+SELECT seq, id1, id2, round(cost::numeric, 3) from pgr_trsp(
     'select  id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost from edge_table',
     1, 3,
     true, true,
@@ -37,7 +37,7 @@ SELECT seq, id1, id2, cost::text from pgr_trsp(
 
 PREPARE q32 AS
 SELECT (row_number() over() -1)::INTEGER, node::INTEGER,
-(CASE WHEN edge = -2 THEN -1 ELSE edge END)::INTEGER, cost::text
+(CASE WHEN edge = -2 THEN -1 ELSE edge END)::INTEGER, round(cost::numeric, 3)
 FROM pgr_dijkstraVia(
     'select  id, source, target, cost, reverse_cost from edge_table',
     ARRAY[1, 10, 12, 4, 3],
@@ -90,9 +90,7 @@ FROM pgr_dijkstraVia(
 SELECT is_empty('q41', '5: Undirected: No path from 1 to 1');
 SELECT set_eq('q51','q52','6: Undirected: without retrictions returns the same as pgr_dijkstra');
 
-SELECT todo_start('dont know why its failing');
 SELECT set_eq('q61','q62','7: Undirected: with retrictions returns expected path');
-SELECT todo_end();
 -- Finish the tests and clean up.
 SELECT * FROM finish();
 ROLLBACK
