@@ -6,42 +6,62 @@
 
  ------
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
 #include "cpp_common/xy_vertex.h"
+#if BOOST_Geometry_VERSION_OK
+#include <boost/geometry/io/wkt/write.hpp>
+#else
+#include <boost/bgeometry/io/wkt/write.hpp>
+#endif
 
 #include <vector>
+#include <limits>
 #include <algorithm>
 
 #include "cpp_common/pgr_assert.h"
 
+namespace {
+
+template<typename T>
+typename std::enable_if<!std::numeric_limits<T>::is_integer, bool>::type
+    almost_equal(T x, T y, int ulp) {
+    // the machine epsilon has to be scaled to the magnitude of the values used
+    // and multiplied by the desired precision in ULPs (units in the last place)
+    return std::abs(x-y) <= std::numeric_limits<T>::epsilon() * std::abs(x+y) * ulp
+        // unless the result is subnormal
+        || std::abs(x-y) < std::numeric_limits<T>::min();
+}
+
+}  // namespace
 
 namespace pgrouting {
 
 
 std::ostream& operator<<(std::ostream& log, const XY_vertex &v) {
-    log << v.id << "(" << v.point.x() << "," << v.point.y() << ")";
+    log << v.id << "-" << bg::wkt(v.point);
     return log;
 }
 
 bool
 XY_vertex::operator==(const XY_vertex &rhs) const {
     if (&rhs == this) return true;
-    return this->id == rhs.id && point == rhs.point;
+    return this->id == rhs.id &&
+        almost_equal(point.x(), rhs.point.x(), 2) && almost_equal(point.y(), rhs.point.y(), 2);
 }
 
 
